@@ -2,7 +2,7 @@ package Inline;
 
 use strict;
 require 5.006;
-$Inline::VERSION = '0.54_05';
+$Inline::VERSION = '0.55_01';
 $Inline::VERSION = eval $Inline::VERSION;
 
 use AutoLoader 'AUTOLOAD';
@@ -514,16 +514,7 @@ sub check_installed {
 sub load {
     my $o = shift;
 
-    if ($o->{CONFIG}{_INSTALL_}) {
-	my $inline = "$o->{API}{modfname}.inl";
-	open INLINE, "> $inline"
-	  or croak M24_open_for_output_failed($inline);
-	print INLINE "*** AUTOGENERATED by Inline.pm ***\n\n";
-	print INLINE "This file satisfies the make dependency for ";
-	print INLINE "$o->{API}{modfname}.pm\n";
-	close INLINE;
-	return;
-    }
+    return if $o->{CONFIG}{_INSTALL_};
 
     my ($pkg, $module) = @{$o->{API}}{qw(pkg module)};
     croak M42_usage_loader() unless $o->{INLINE}{ILSM_type} eq 'compiled';
@@ -548,6 +539,23 @@ END
     croak M43_error_bootstrap($module, $@) if $@;
 }
 
+#==============================================================================
+# Create file that satisfies the Makefile dependency for this object
+#==============================================================================
+
+sub satisfy_makefile_dep {
+    my $o = shift;
+
+       my $inline = $o->{API}{modinlname};
+       open INLINE, "> $inline"
+         or croak M24_open_for_output_failed($inline);
+       print INLINE "*** AUTOGENERATED by Inline.pm ***\n\n";
+       print INLINE "This file satisfies the make dependency for ";
+       print INLINE "$o->{API}{module}\n";
+       close INLINE;
+       return;
+}
+
 #==============================================================================
 # Process the config options that apply to all Inline sections
 #==============================================================================
@@ -983,6 +991,7 @@ sub install {
     my @modparts = split(/::/,$o->{API}{module});
     $o->{API}{modfname} = $modparts[-1];
     $o->{API}{modpname} = File::Spec->catdir(@modparts);
+    $o->{API}{modinlname} = join('-',@modparts).'.inl';
     $o->{API}{suffix} = $o->{INLINE}{ILSM_suffix};
     $o->{API}{build_dir} = File::Spec->catdir($o->{INLINE}{DIRECTORY},'build',
                                               $o->{API}{modpname});
@@ -1061,16 +1070,13 @@ sub env_untaint {
       }
     }
 
+    # only accept dirs that are absolute and not world-writable
     $ENV{PATH} = $^O eq 'MSWin32' ?
                  join ';', grep {not /^\./ and -d $_
 				  } split /;/, $ENV{PATH}
                  :
-                 join ':', grep {not /^\./ and -d $_ and not -w $_ || -W $_
+                 join ':', grep {/^\// and -d $_ and not ((stat($_))[2] & 0022)
                                   } split /:/, $ENV{PATH};
-# Was:
-#                join ':', grep {not /^\./ and -d $_ and
-#		                 not ((stat($_))[2] & 0022)
-#				  } split /:/, $ENV{PATH};
 
     map {($_) = /(.*)/} @INC;
 
@@ -1082,6 +1088,7 @@ sub obj_untaint {
     my $o = shift;
     warn "In Inline::obj_untaint() : Blindly untainting tainted fields in Inline object.\n" unless $o->{CONFIG}{NO_UNTAINT_WARN};
     ($o->{INLINE}{ILSM_module}) = $o->{INLINE}{ILSM_module} =~ /(.*)/;
+    ($o->{API}{directory}) = $o->{API}{directory} =~ /(.*)/;
     ($o->{API}{build_dir}) = $o->{API}{build_dir} =~ /(.*)/;
     ($o->{CONFIG}{DIRECTORY}) = $o->{CONFIG}{DIRECTORY} =~ /(.*)/;
     ($o->{API}{install_lib}) = $o->{API}{install_lib} =~ /(.*)/;
@@ -1240,7 +1247,7 @@ END
 }
 
 #==============================================================================
-# Hand off this invokation to Inline::MakeMaker
+# Hand off this invocation to Inline::MakeMaker
 #==============================================================================
 sub maker_utils {
     require Inline::MakeMaker;
